Index: trunk/ippTools/src/pxchip.c
===================================================================
--- trunk/ippTools/src/pxchip.c	(revision 14018)
+++ trunk/ippTools/src/pxchip.c	(revision 14023)
@@ -57,5 +57,5 @@
 
 bool pxchipQueueByExpTag(pxConfig *config,
-                         psString exp_tag,
+                         psString exp_id,
                          psString workdir,
                          psString label,
@@ -96,5 +96,5 @@
 #endif
 
     // populate the chipInputImfile table from rawImfile based on exp_tag,
     // where the coresponding newExp.state entry is set to stop
     psString query = pxDataGetCached("chiptool_queuerawimfile.sql");
@@ -104,6 +104,6 @@
     }
 
-    // queue the imfiles for the exp_tag
-    if (!p_psDBRunQuery(config->dbh, query, exp_tag)) {
+    // queue the imfiles for the exp_id
+    if (!p_psDBRunQuery(config->dbh, query, exp_id)) {
         psError(PS_ERR_UNKNOWN, false, "database error");
         return false;
@@ -96,5 +96,5 @@
 #endif
 
-    // populate the chipInputImfile table from rawImfile based on exp_tag,
+    // populate the chipInputImfile table from rawImfile based on exp_id,
     // where the coresponding newExp.state entry is set to stop
     psString query = pxDataGetCached("chiptool_queuerawimfile.sql");
